@@ -1,7 +1,10 @@
+## no critic: Modules::ProhibitAutomaticExportation
 package Data::ModeMerge;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-15'; # DATE
+our $DIST = 'Data-ModeMerge'; # DIST
+our $VERSION = '0.360'; # VERSION
 
 use 5.010001;
 use strict;
@@ -354,7 +357,7 @@ Data::ModeMerge - Merge two nested data structures, with merging modes and optio
 
 =head1 VERSION
 
-This document describes version 0.35 of Data::ModeMerge (from Perl distribution Data-ModeMerge), released on 2016-07-22.
+This document describes version 0.360 of Data::ModeMerge (from Perl distribution Data-ModeMerge), released on 2021-08-15.
 
 =head1 SYNOPSIS
 
@@ -775,9 +778,25 @@ use Data::ModeMerge)
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Steven Haryanto (on PC)
+
+=over 4
+
+=item *
+
+Steven Haryanto (on PC) <stevenharyanto@gmail.com>
+
+=item *
+
+Steven Haryanto <steven@masterweb.net>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015, 2013, 2012, 2011, 2010 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
